﻿using System.Windows;
using System.Windows.Media;
using Telerik.Windows.Controls;

namespace CustomDropShadowEffect
{
    public class ThemeExtensions
    {
        public static Color GetAlternativeColor(DependencyObject obj)
        {
            return (Color)obj.GetValue(AlternativeColorProperty);
        }

        public static void SetAlternativeColor(DependencyObject obj, Color value)
        {
            obj.SetValue(AlternativeColorProperty, value);
        }

        public static readonly DependencyProperty AlternativeColorProperty =
            DependencyProperty.RegisterAttached("AlternativeColor", typeof(Color), typeof(ThemeExtensions), new PropertyMetadata(OnAlternativeColorPropertyChanged));

        private static void OnAlternativeColorPropertyChanged(DependencyObject d, DependencyPropertyChangedEventArgs e)
        {
            var freezable = FreezeResource(new SolidColorBrush((Color)e.NewValue));

            RemoveAndAddResource((d as FrameworkElement), FluentResourceKey.AlternativeBrush, freezable);
        }

        internal static Freezable FreezeResource(object resource)
        {
            Freezable freezable = resource as Freezable;
            if (freezable != null)
            {
                freezable.Freeze();
            }

            return freezable;
        }

        internal static void RemoveAndAddResource(FrameworkElement element, ResourceKey key, Freezable freezable)
        {
            element.Resources.Remove(key);
            element.Resources.Add(key, freezable);
        }
    }
}
